Lage/Redigere tabell

Lage/Redigere tabell | IF

Lage tabell-knappen åpner et nytt vindauge, ved hjelp av dette vindauget kan du lage tabeller.
Feltforklaring:

Kolonner | Antall kolonner i tabellen.
Rader | Antall rader i tabellen.
Celleutfylling | Antall pixler utfylling i kvar celle.
Cellemellomrom | Antall pixler mellomrom mellom cellene.
Justering | Tabellens justering.
Rammebredde | Rammens bredde.
Bredde | Bredde i pixler.
Høgde | Høgde i pixler.
Stil | Stilmal på tabellen.

Gå til: Innhaldsoversikt | Toppen